@@ -91,10 +91,12 @@ class PostEndpoints:
         self.__check_fields(data=data, required_fields=required_fields, allowed_fields=allowed_fields)
 
         base_body = {
-            "Afasemployeenumber": data["afas_employee_id"],
-            "Employeenumber": data["sap_employee_id"],
-            "Startdate": data["start_date"],
-            "Enddate": data["end_date"]
+            'PersonalData': {
+                "Afasemployeenumber": data["afas_employee_id"],
+                "Employeenumber": data["sap_employee_id"],
+                "Startdate": data["start_date"],
+                "Enddate": data["end_date"]
+            }
         }
         fields_to_update = {}
 
